@@ -95,8 +95,6 @@ from ncbi.datasets.openapi.model.v1_gene_dataset_request import V1GeneDatasetReq
 from ncbi.datasets.openapi.model.v1_gene_dataset_request import V1GeneDatasetRequest as V1alpha1GeneDatasetRequest
 from ncbi.datasets.openapi.model.v1_gene_dataset_request_content_type import V1GeneDatasetRequestContentType
 from ncbi.datasets.openapi.model.v1_gene_dataset_request_content_type import V1GeneDatasetRequestContentType as V1alpha1GeneDatasetRequestContentType
-from ncbi.datasets.openapi.model.v1_gene_dataset_request_gene_ids import V1GeneDatasetRequestGeneIds
-from ncbi.datasets.openapi.model.v1_gene_dataset_request_gene_ids import V1GeneDatasetRequestGeneIds as V1alpha1GeneDatasetRequestGeneIds
 from ncbi.datasets.openapi.model.v1_gene_dataset_request_sort import V1GeneDatasetRequestSort
 from ncbi.datasets.openapi.model.v1_gene_dataset_request_sort import V1GeneDatasetRequestSort as V1alpha1GeneDatasetRequestSort
 from ncbi.datasets.openapi.model.v1_gene_dataset_request_sort_field import V1GeneDatasetRequestSortField
@@ -227,129 +225,19 @@ from ncbi.datasets.openapi.model.v1_warning_gene_warning_code import V1WarningGe
 from ncbi.datasets.openapi.model.v1_warning_gene_warning_code import V1WarningGeneWarningCode as V1alpha1WarningGeneWarningCode
 from ncbi.datasets.openapi.model.v1_warning_replaced_id import V1WarningReplacedId
 from ncbi.datasets.openapi.model.v1_warning_replaced_id import V1WarningReplacedId as V1alpha1WarningReplacedId
-from ncbi.datasets.openapi.model.v1reports_amr_finder_plus import V1reportsAmrFinderPlus
-from ncbi.datasets.openapi.model.v1reports_amr_finder_plus import V1reportsAmrFinderPlus as V1alpha1reportsAmrFinderPlus
-from ncbi.datasets.openapi.model.v1reports_annotated_assemblies import V1reportsAnnotatedAssemblies
-from ncbi.datasets.openapi.model.v1reports_annotated_assemblies import V1reportsAnnotatedAssemblies as V1alpha1reportsAnnotatedAssemblies
-from ncbi.datasets.openapi.model.v1reports_annotation import V1reportsAnnotation
-from ncbi.datasets.openapi.model.v1reports_annotation import V1reportsAnnotation as V1alpha1reportsAnnotation
-from ncbi.datasets.openapi.model.v1reports_annotation_info import V1reportsAnnotationInfo
-from ncbi.datasets.openapi.model.v1reports_annotation_info import V1reportsAnnotationInfo as V1alpha1reportsAnnotationInfo
-from ncbi.datasets.openapi.model.v1reports_assembly_data_report import V1reportsAssemblyDataReport
-from ncbi.datasets.openapi.model.v1reports_assembly_data_report import V1reportsAssemblyDataReport as V1alpha1reportsAssemblyDataReport
-from ncbi.datasets.openapi.model.v1reports_assembly_info import V1reportsAssemblyInfo
-from ncbi.datasets.openapi.model.v1reports_assembly_info import V1reportsAssemblyInfo as V1alpha1reportsAssemblyInfo
-from ncbi.datasets.openapi.model.v1reports_assembly_stats import V1reportsAssemblyStats
-from ncbi.datasets.openapi.model.v1reports_assembly_stats import V1reportsAssemblyStats as V1alpha1reportsAssemblyStats
-from ncbi.datasets.openapi.model.v1reports_bio_project import V1reportsBioProject
-from ncbi.datasets.openapi.model.v1reports_bio_project import V1reportsBioProject as V1alpha1reportsBioProject
-from ncbi.datasets.openapi.model.v1reports_bio_project_lineage import V1reportsBioProjectLineage
-from ncbi.datasets.openapi.model.v1reports_bio_project_lineage import V1reportsBioProjectLineage as V1alpha1reportsBioProjectLineage
-from ncbi.datasets.openapi.model.v1reports_bio_sample_attribute import V1reportsBioSampleAttribute
-from ncbi.datasets.openapi.model.v1reports_bio_sample_attribute import V1reportsBioSampleAttribute as V1alpha1reportsBioSampleAttribute
-from ncbi.datasets.openapi.model.v1reports_bio_sample_contact import V1reportsBioSampleContact
-from ncbi.datasets.openapi.model.v1reports_bio_sample_contact import V1reportsBioSampleContact as V1alpha1reportsBioSampleContact
-from ncbi.datasets.openapi.model.v1reports_bio_sample_description import V1reportsBioSampleDescription
-from ncbi.datasets.openapi.model.v1reports_bio_sample_description import V1reportsBioSampleDescription as V1alpha1reportsBioSampleDescription
-from ncbi.datasets.openapi.model.v1reports_bio_sample_descriptor import V1reportsBioSampleDescriptor
-from ncbi.datasets.openapi.model.v1reports_bio_sample_descriptor import V1reportsBioSampleDescriptor as V1alpha1reportsBioSampleDescriptor
-from ncbi.datasets.openapi.model.v1reports_bio_sample_id import V1reportsBioSampleId
-from ncbi.datasets.openapi.model.v1reports_bio_sample_id import V1reportsBioSampleId as V1alpha1reportsBioSampleId
-from ncbi.datasets.openapi.model.v1reports_bio_sample_owner import V1reportsBioSampleOwner
-from ncbi.datasets.openapi.model.v1reports_bio_sample_owner import V1reportsBioSampleOwner as V1alpha1reportsBioSampleOwner
-from ncbi.datasets.openapi.model.v1reports_bio_sample_status import V1reportsBioSampleStatus
-from ncbi.datasets.openapi.model.v1reports_bio_sample_status import V1reportsBioSampleStatus as V1alpha1reportsBioSampleStatus
-from ncbi.datasets.openapi.model.v1reports_biosample import V1reportsBiosample
-from ncbi.datasets.openapi.model.v1reports_biosample import V1reportsBiosample as V1alpha1reportsBiosample
-from ncbi.datasets.openapi.model.v1reports_busco_stat import V1reportsBuscoStat
-from ncbi.datasets.openapi.model.v1reports_busco_stat import V1reportsBuscoStat as V1alpha1reportsBuscoStat
-from ncbi.datasets.openapi.model.v1reports_closest_reference import V1reportsClosestReference
-from ncbi.datasets.openapi.model.v1reports_closest_reference import V1reportsClosestReference as V1alpha1reportsClosestReference
-from ncbi.datasets.openapi.model.v1reports_conserved_domain import V1reportsConservedDomain
-from ncbi.datasets.openapi.model.v1reports_conserved_domain import V1reportsConservedDomain as V1alpha1reportsConservedDomain
-from ncbi.datasets.openapi.model.v1reports_element import V1reportsElement
-from ncbi.datasets.openapi.model.v1reports_element import V1reportsElement as V1alpha1reportsElement
-from ncbi.datasets.openapi.model.v1reports_feature_counts import V1reportsFeatureCounts
-from ncbi.datasets.openapi.model.v1reports_feature_counts import V1reportsFeatureCounts as V1alpha1reportsFeatureCounts
-from ncbi.datasets.openapi.model.v1reports_gene_counts import V1reportsGeneCounts
-from ncbi.datasets.openapi.model.v1reports_gene_counts import V1reportsGeneCounts as V1alpha1reportsGeneCounts
-from ncbi.datasets.openapi.model.v1reports_gene_descriptor import V1reportsGeneDescriptor
-from ncbi.datasets.openapi.model.v1reports_gene_descriptor import V1reportsGeneDescriptor as V1alpha1reportsGeneDescriptor
 from ncbi.datasets.openapi.model.v1reports_gene_descriptor_gene_type import V1reportsGeneDescriptorGeneType
 from ncbi.datasets.openapi.model.v1reports_gene_descriptor_gene_type import V1reportsGeneDescriptorGeneType as V1alpha1reportsGeneDescriptorGeneType
 from ncbi.datasets.openapi.model.v1reports_gene_descriptor_rna_type import V1reportsGeneDescriptorRnaType
 from ncbi.datasets.openapi.model.v1reports_gene_descriptor_rna_type import V1reportsGeneDescriptorRnaType as V1alpha1reportsGeneDescriptorRnaType
-from ncbi.datasets.openapi.model.v1reports_gene_descriptors import V1reportsGeneDescriptors
-from ncbi.datasets.openapi.model.v1reports_gene_descriptors import V1reportsGeneDescriptors as V1alpha1reportsGeneDescriptors
-from ncbi.datasets.openapi.model.v1reports_genomic_location import V1reportsGenomicLocation
-from ncbi.datasets.openapi.model.v1reports_genomic_location import V1reportsGenomicLocation as V1alpha1reportsGenomicLocation
-from ncbi.datasets.openapi.model.v1reports_genomic_region import V1reportsGenomicRegion
-from ncbi.datasets.openapi.model.v1reports_genomic_region import V1reportsGenomicRegion as V1alpha1reportsGenomicRegion
 from ncbi.datasets.openapi.model.v1reports_genomic_region_genomic_region_type import V1reportsGenomicRegionGenomicRegionType
 from ncbi.datasets.openapi.model.v1reports_genomic_region_genomic_region_type import V1reportsGenomicRegionGenomicRegionType as V1alpha1reportsGenomicRegionGenomicRegionType
-from ncbi.datasets.openapi.model.v1reports_lineage_organism import V1reportsLineageOrganism
-from ncbi.datasets.openapi.model.v1reports_lineage_organism import V1reportsLineageOrganism as V1alpha1reportsLineageOrganism
-from ncbi.datasets.openapi.model.v1reports_mature_peptide import V1reportsMaturePeptide
-from ncbi.datasets.openapi.model.v1reports_mature_peptide import V1reportsMaturePeptide as V1alpha1reportsMaturePeptide
-from ncbi.datasets.openapi.model.v1reports_micro_bigge_report import V1reportsMicroBiggeReport
-from ncbi.datasets.openapi.model.v1reports_micro_bigge_report import V1reportsMicroBiggeReport as V1alpha1reportsMicroBiggeReport
-from ncbi.datasets.openapi.model.v1reports_nomenclature_authority import V1reportsNomenclatureAuthority
-from ncbi.datasets.openapi.model.v1reports_nomenclature_authority import V1reportsNomenclatureAuthority as V1alpha1reportsNomenclatureAuthority
-from ncbi.datasets.openapi.model.v1reports_organelle_info import V1reportsOrganelleInfo
-from ncbi.datasets.openapi.model.v1reports_organelle_info import V1reportsOrganelleInfo as V1alpha1reportsOrganelleInfo
-from ncbi.datasets.openapi.model.v1reports_organism import V1reportsOrganism
-from ncbi.datasets.openapi.model.v1reports_organism import V1reportsOrganism as V1alpha1reportsOrganism
 from ncbi.datasets.openapi.model.v1reports_orientation import V1reportsOrientation
 from ncbi.datasets.openapi.model.v1reports_orientation import V1reportsOrientation as V1alpha1reportsOrientation
-from ncbi.datasets.openapi.model.v1reports_pathogen_fasta_defline import V1reportsPathogenFastaDefline
-from ncbi.datasets.openapi.model.v1reports_pathogen_fasta_defline import V1reportsPathogenFastaDefline as V1alpha1reportsPathogenFastaDefline
-from ncbi.datasets.openapi.model.v1reports_prokaryote_gene import V1reportsProkaryoteGene
-from ncbi.datasets.openapi.model.v1reports_prokaryote_gene import V1reportsProkaryoteGene as V1alpha1reportsProkaryoteGene
-from ncbi.datasets.openapi.model.v1reports_prokaryote_gene_location import V1reportsProkaryoteGeneLocation
-from ncbi.datasets.openapi.model.v1reports_prokaryote_gene_location import V1reportsProkaryoteGeneLocation as V1alpha1reportsProkaryoteGeneLocation
 from ncbi.datasets.openapi.model.v1reports_prokaryote_gene_location_completeness import V1reportsProkaryoteGeneLocationCompleteness
 from ncbi.datasets.openapi.model.v1reports_prokaryote_gene_location_completeness import V1reportsProkaryoteGeneLocationCompleteness as V1alpha1reportsProkaryoteGeneLocationCompleteness
-from ncbi.datasets.openapi.model.v1reports_prokaryote_gene_location_defline import V1reportsProkaryoteGeneLocationDefline
-from ncbi.datasets.openapi.model.v1reports_prokaryote_gene_location_defline import V1reportsProkaryoteGeneLocationDefline as V1alpha1reportsProkaryoteGeneLocationDefline
-from ncbi.datasets.openapi.model.v1reports_prokaryote_gene_protein_name_evidence import V1reportsProkaryoteGeneProteinNameEvidence
-from ncbi.datasets.openapi.model.v1reports_prokaryote_gene_protein_name_evidence import V1reportsProkaryoteGeneProteinNameEvidence as V1alpha1reportsProkaryoteGeneProteinNameEvidence
-from ncbi.datasets.openapi.model.v1reports_protein import V1reportsProtein
-from ncbi.datasets.openapi.model.v1reports_protein import V1reportsProtein as V1alpha1reportsProtein
 from ncbi.datasets.openapi.model.v1reports_purpose_of_sampling import V1reportsPurposeOfSampling
 from ncbi.datasets.openapi.model.v1reports_purpose_of_sampling import V1reportsPurposeOfSampling as V1alpha1reportsPurposeOfSampling
-from ncbi.datasets.openapi.model.v1reports_range import V1reportsRange
-from ncbi.datasets.openapi.model.v1reports_range import V1reportsRange as V1alpha1reportsRange
-from ncbi.datasets.openapi.model.v1reports_read_to_assembly_coverage import V1reportsReadToAssemblyCoverage
-from ncbi.datasets.openapi.model.v1reports_read_to_assembly_coverage import V1reportsReadToAssemblyCoverage as V1alpha1reportsReadToAssemblyCoverage
-from ncbi.datasets.openapi.model.v1reports_seq_range_set import V1reportsSeqRangeSet
-from ncbi.datasets.openapi.model.v1reports_seq_range_set import V1reportsSeqRangeSet as V1alpha1reportsSeqRangeSet
-from ncbi.datasets.openapi.model.v1reports_seq_range_set_fasta import V1reportsSeqRangeSetFasta
-from ncbi.datasets.openapi.model.v1reports_seq_range_set_fasta import V1reportsSeqRangeSetFasta as V1alpha1reportsSeqRangeSetFasta
-from ncbi.datasets.openapi.model.v1reports_seq_range_with_assembly import V1reportsSeqRangeWithAssembly
-from ncbi.datasets.openapi.model.v1reports_seq_range_with_assembly import V1reportsSeqRangeWithAssembly as V1alpha1reportsSeqRangeWithAssembly
-from ncbi.datasets.openapi.model.v1reports_sequence_info import V1reportsSequenceInfo
-from ncbi.datasets.openapi.model.v1reports_sequence_info import V1reportsSequenceInfo as V1alpha1reportsSequenceInfo
-from ncbi.datasets.openapi.model.v1reports_taxonomy import V1reportsTaxonomy
-from ncbi.datasets.openapi.model.v1reports_taxonomy import V1reportsTaxonomy as V1alpha1reportsTaxonomy
-from ncbi.datasets.openapi.model.v1reports_transcript import V1reportsTranscript
-from ncbi.datasets.openapi.model.v1reports_transcript import V1reportsTranscript as V1alpha1reportsTranscript
 from ncbi.datasets.openapi.model.v1reports_transcript_transcript_type import V1reportsTranscriptTranscriptType
 from ncbi.datasets.openapi.model.v1reports_transcript_transcript_type import V1reportsTranscriptTranscriptType as V1alpha1reportsTranscriptTranscriptType
-from ncbi.datasets.openapi.model.v1reports_virus_annotation import V1reportsVirusAnnotation
-from ncbi.datasets.openapi.model.v1reports_virus_annotation import V1reportsVirusAnnotation as V1alpha1reportsVirusAnnotation
-from ncbi.datasets.openapi.model.v1reports_virus_assembly import V1reportsVirusAssembly
-from ncbi.datasets.openapi.model.v1reports_virus_assembly import V1reportsVirusAssembly as V1alpha1reportsVirusAssembly
-from ncbi.datasets.openapi.model.v1reports_virus_assembly_collection_location import V1reportsVirusAssemblyCollectionLocation
-from ncbi.datasets.openapi.model.v1reports_virus_assembly_collection_location import V1reportsVirusAssemblyCollectionLocation as V1alpha1reportsVirusAssemblyCollectionLocation
 from ncbi.datasets.openapi.model.v1reports_virus_assembly_completeness import V1reportsVirusAssemblyCompleteness
 from ncbi.datasets.openapi.model.v1reports_virus_assembly_completeness import V1reportsVirusAssemblyCompleteness as V1alpha1reportsVirusAssemblyCompleteness
-from ncbi.datasets.openapi.model.v1reports_virus_assembly_isolate import V1reportsVirusAssemblyIsolate
-from ncbi.datasets.openapi.model.v1reports_virus_assembly_isolate import V1reportsVirusAssemblyIsolate as V1alpha1reportsVirusAssemblyIsolate
-from ncbi.datasets.openapi.model.v1reports_virus_gene import V1reportsVirusGene
-from ncbi.datasets.openapi.model.v1reports_virus_gene import V1reportsVirusGene as V1alpha1reportsVirusGene
-from ncbi.datasets.openapi.model.v1reports_virus_peptide import V1reportsVirusPeptide
-from ncbi.datasets.openapi.model.v1reports_virus_peptide import V1reportsVirusPeptide as V1alpha1reportsVirusPeptide
-from ncbi.datasets.openapi.model.v1reports_virus_peptide_uni_prot_id import V1reportsVirusPeptideUniProtId
-from ncbi.datasets.openapi.model.v1reports_virus_peptide_uni_prot_id import V1reportsVirusPeptideUniProtId as V1alpha1reportsVirusPeptideUniProtId
-from ncbi.datasets.openapi.model.v1reports_wgs_info import V1reportsWGSInfo
-from ncbi.datasets.openapi.model.v1reports_wgs_info import V1reportsWGSInfo as V1alpha1reportsWGSInfo
